FileAttributes

Struct FileAttributes 

pub struct FileAttributes { /* private fields */ }

Implementations

Source

impl FileAttributes

pub fn builder() -> FileAttributesBuilder<((), (), (), (), (), (), (), (), (), (), (), ())>

Create a builder for building FileAttributes. On the builder, call .mode(...), .size(...)(optional), .nlink(...)(optional), .uid(...)(optional), .gid(...)(optional), .rdev(...)(optional), .blksize(...)(optional), .blocks(...)(optional), .atime(...)(optional), .mtime(...)(optional), .ctime(...)(optional), .ttl(...)(optional) to set the values of the fields. Finally, call .build() to create the instance of FileAttributes.

Examples found in repository?
examples/memfs.rs (line 51)
49    fn new(data: Vec<u8>) -> File {
50        File {
51            attrs: FileAttributes::builder()
52                .size(data.len() as u64)
53                .mode(libc::S_IFREG | 0o755)
54                .build(),
55
56            data,
57        }
58    }
Source

impl FileAttributes

pub fn mode(&self) -> u32

pub fn size(&self) -> u64

Examples found in repository?
examples/memfs.rs (line 61)
60    fn size(&self) -> usize {
61        self.attrs.size() as usize
62    }
pub fn uid(&self) -> u32

pub fn gid(&self) -> u32

pub fn rdev(&self) -> u32

pub fn blksize(&self) -> u32

pub fn blocks(&self) -> u64

pub fn atime(&self) -> Duration

pub fn mtime(&self) -> Duration

pub fn ctime(&self) -> Duration

pub fn ttl(&self) -> Duration

Note

ttl means time to live This is not time to live, such as you’d go live on Twitch. It means time to live, as in the remaining time you have left alive. I spent way too long misunderstanding that.

pub fn set_mode(&mut self, mode: u32)

pub fn set_size(&mut self, size: u64)

Examples found in repository?
examples/memfs.rs (line 178)
165    fn write<T: BufRead>(&mut self, ino: INode, offset: u64, size: u32, mut buf: T) -> Result<u32> {
166        let file = self.inodes.get_mut(ino).ok_or(FSError::NoEntry)?;
167        let file = file.as_file_mut().ok_or(FSError::NotFile)?;
168
169        let offset = offset as usize;
170        let size = size as usize;
171
172        file.data
173            .resize(std::cmp::max(file.size(), offset + size), 0);
174
175        buf.read_exact(&mut file.data[offset..offset + size])
176            .unwrap();
177
178        file.attrs.set_size((offset + size) as u64);
179
180        Ok(size as u32)
181    }
pub fn set_uid(&mut self, uid: u32)

pub fn set_gid(&mut self, gid: u32)

pub fn set_rdev(&mut self, rdev: u32)

pub fn set_blksize(&mut self, blksize: u32)

pub fn set_blocks(&mut self, blocks: u64)

pub fn set_atime(&mut self, atime: Duration)

pub fn set_mtime(&mut self, mtime: Duration)

pub fn set_ctime(&mut self, ctime: Duration)

pub fn set_ttl(&mut self, ttl: Duration)

pub fn apply_attrs(&mut self, attrs: SetFileAttributes)

Examples found in repository?
examples/memfs.rs (line 188)
183    fn setattr(&mut self, ino: INode, attrs: SetFileAttributes) -> Result<FileAttributes> {
184        let entry = self.inodes.get_mut(ino).ok_or(FSError::NoEntry)?;
185
186        match entry.kind_mut() {
187            INodeKind::Directory(dir) => dir.apply_attrs(attrs),
188            INodeKind::File(file) => file.attrs.apply_attrs(attrs),
189        };
190
191        Ok(entry.getattrs())
192    }